@@ -1,6 +1,6 @@
 package Parse::Dia::SQL::Utils;
 
-# $Id: Utils.pm,v 1.8 2009/07/12 19:27:37 aff Exp $
+# $Id: Utils.pm,v 1.12 2010/05/27 09:22:38 aff Exp $
 
 =pod
 
@@ -215,6 +215,8 @@ sub get_string_from_node {
     }
   }
 
+	return if !$retval; # Skip escaping if empty
+
   #	$retval =~ s/^#?(.*)#?$/$1/g;
   $retval =~ s/^#//;
   $retval =~ s/#$//;
@@ -514,7 +516,6 @@ sub check_att_list_types {
     }
   }
 
-  # if $opt_M is set, then $mismatches == 0 anyway
   return $mismatches == 0;
 }
 
@@ -526,6 +527,8 @@ the types in a list of foreign key attributes.
 Returns base type of some DMBS specific types (eg in PostgreSQL serial
 is integer).
 
+AFF note:  This is better implemented in each sql formatter class.
+
 =cut
 
 sub get_base_type {
@@ -535,9 +538,19 @@ sub get_base_type {
   if ( $db eq 'postgres' ) {
 
     # handle PostgreSQL database type
-    if ( lc($typeName) eq 'serial' ) {
+    if ( lc($typeName) eq 'serial' or lc($typeName) eq 'int4' or lc($typeName) eq 'int') {
+			$self->{log}->info(qq{Replaced $typeName with integer}) if $self->{log}->is_info();
       return 'integer';
     }
+    if ( lc($typeName) eq 'int2' ) {
+			$self->{log}->info(qq{Replaced $typeName with smallint}) if $self->{log}->is_info();
+      return 'smallint';
+    }
+    if ( lc($typeName) eq 'int8' ) {
+			$self->{log}->info(qq{Replaced $typeName with bigint}) if $self->{log}->is_info();
+      return 'bigint';
+    }
+
     return $typeName;
   }
   elsif ( $db eq 'templateDBMStype' ) {
@@ -878,6 +891,29 @@ sub _check_object_version {
   return 1;
 }
 
+# Split a type definition 'type(nn)' into 'type', '(nn)'
+sub split_type {
+	my $self = shift;
+	my $type = shift;
+
+	if(!$type) {
+		$self->{log}->warn("Missing type");
+		return;
+	}
+
+	$type =~ m/^([^(]*)(\([^)]+\))?$/;
+	my ($name, $size) = ($1, $2);
+	if(!$name) {
+		$self->{log}->warn("Malformed type name $type");
+		return;
+	}
+
+	if ($size) {
+		return ($name,$size);
+	} else {
+		return ($name);
+	}
+}
 
 # =head2 parseExtras
 
